/*
 * The Clear BSD License
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted (subject to the limitations in the disclaimer below) provided
 * that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY THIS LICENSE.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef _PIN_MUX_H_
#define _PIN_MUX_H_

/***********************************************************************************************************************
 * Definitions
 **********************************************************************************************************************/

/*! @brief Direction type  */
typedef enum _pin_mux_direction
{
    kPIN_MUX_DirectionInput = 0U,        /* Input direction */
    kPIN_MUX_DirectionOutput = 1U,       /* Output direction */
    kPIN_MUX_DirectionInputOrOutput = 2U /* Input or output direction */
} pin_mux_direction_t;

/*!
 * @addtogroup pin_mux
 * @{
 */

/***********************************************************************************************************************
 * API
 **********************************************************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif


/*!
 * @brief FTM3 channel 5 output source: FTM3_CH5 pin is output of FTM3 channel 5 output */
#define SOPT8_FTM3OCH5SRC_FTM 0x00u
/*!
 * @brief FTM3 channel 6 output source: FTM3_CH6 pin is output of FTM3 channel 6 output */
#define SOPT8_FTM3OCH6SRC_FTM 0x00u

/*! @name PORTC14 (number 86), OpenSDA_UART
  @{ */
#define BOARD_DEBUG_UART_RX_PERIPHERAL LPUART4   /*!<@brief Device name: LPUART4 */
#define BOARD_DEBUG_UART_RX_SIGNAL RX            /*!<@brief LPUART4 signal: RX */
#define BOARD_DEBUG_UART_RX_PORT PORTC           /*!<@brief PORT device name: PORTC */
#define BOARD_DEBUG_UART_RX_PIN 14U              /*!<@brief PORTC pin index: 14 */
#define BOARD_DEBUG_UART_RX_PIN_NAME LPUART4_RX  /*!<@brief Pin name */
#define BOARD_DEBUG_UART_RX_LABEL "OpenSDA_UART" /*!<@brief Label */
#define BOARD_DEBUG_UART_RX_NAME "DEBUG_UART_RX" /*!<@brief Identifier name */
                                                 /* @} */

/*! @name PORTC10 (number 82), J1[12]/D5/LEDRGB_BLUE
  @{ */
#define BOARD_LED_BLUE_PERIPHERAL FTM3               /*!<@brief Device name: FTM3 */
#define BOARD_LED_BLUE_SIGNAL CH                     /*!<@brief FTM3 signal: CH */
#define BOARD_LED_BLUE_PORT PORTC                    /*!<@brief PORT device name: PORTC */
#define BOARD_LED_BLUE_PIN 10U                       /*!<@brief PORTC pin index: 10 */
#define BOARD_LED_BLUE_CHANNEL 6                     /*!<@brief FTM3 channel: 6 */
#define BOARD_LED_BLUE_PIN_NAME FTM3_CH6             /*!<@brief Pin name */
#define BOARD_LED_BLUE_LABEL "J1[12]/D5/LEDRGB_BLUE" /*!<@brief Label */
#define BOARD_LED_BLUE_NAME "LED_BLUE"               /*!<@brief Identifier name */
                                                     /* @} */

/*! @name PORTC15 (number 87), OpenSDA_UART
  @{ */
#define BOARD_DEBUG_UART_TX_PERIPHERAL LPUART4   /*!<@brief Device name: LPUART4 */
#define BOARD_DEBUG_UART_TX_SIGNAL TX            /*!<@brief LPUART4 signal: TX */
#define BOARD_DEBUG_UART_TX_PORT PORTC           /*!<@brief PORT device name: PORTC */
#define BOARD_DEBUG_UART_TX_PIN 15U              /*!<@brief PORTC pin index: 15 */
#define BOARD_DEBUG_UART_TX_PIN_NAME LPUART4_TX  /*!<@brief Pin name */
#define BOARD_DEBUG_UART_TX_LABEL "OpenSDA_UART" /*!<@brief Label */
#define BOARD_DEBUG_UART_TX_NAME "DEBUG_UART_TX" /*!<@brief Identifier name */
                                                 /* @} */

/*! @name PORTC9 (number 81), J1[16]/D7/LEDRGB_GREEN
  @{ */
#define BOARD_LED_GREEN_PERIPHERAL FTM3                /*!<@brief Device name: FTM3 */
#define BOARD_LED_GREEN_SIGNAL CH                      /*!<@brief FTM3 signal: CH */
#define BOARD_LED_GREEN_PORT PORTC                     /*!<@brief PORT device name: PORTC */
#define BOARD_LED_GREEN_PIN 9U                         /*!<@brief PORTC pin index: 9 */
#define BOARD_LED_GREEN_CHANNEL 5                      /*!<@brief FTM3 channel: 5 */
#define BOARD_LED_GREEN_PIN_NAME FTM3_CH5              /*!<@brief Pin name */
#define BOARD_LED_GREEN_LABEL "J1[16]/D7/LEDRGB_GREEN" /*!<@brief Label */
#define BOARD_LED_GREEN_NAME "LED_GREEN"               /*!<@brief Identifier name */
                                                       /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPins(void);

/*! @name PORTA1 (number 37), J2[18]/J12[4]/U6[6]/D14/I2C SDA
  @{ */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_PERIPHERAL I2C3                         /*!<@brief Device name: I2C3 */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_SIGNAL SDA                              /*!<@brief I2C3 signal: SDA */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_PORT PORTA                              /*!<@brief PORT device name: PORTA */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_PIN 1U                                  /*!<@brief PORTA pin index: 1 */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_PIN_NAME I2C3_SDA                       /*!<@brief Pin name */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_LABEL "J2[18]/J12[4]/U6[6]/D14/I2C SDA" /*!<@brief Label */
#define BOARD_I2C_CONFIGUREPINS_I2C_SDA_NAME "I2C_SDA"                          /*!<@brief Identifier name */
                                                                                /* @} */

/*! @name PORTA2 (number 38), J2[20]J12[3]/J19[6]/U6[4]/I2C_SCL
  @{ */
/*!
 * @brief Device name: I2C3 */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_PERIPHERAL I2C3
/*!
 * @brief I2C3 signal: SCL */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_SIGNAL SCL
/*!
 * @brief PORT device name: PORTA */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_PORT PORTA
/*!
 * @brief PORTA pin index: 2 */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_PIN 2U
/*!
 * @brief Pin name */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_PIN_NAME I2C3_SCL
/*!
 * @brief Label */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_LABEL "J2[20]J12[3]/J19[6]/U6[4]/I2C_SCL"
/*!
 * @brief Identifier name */
#define BOARD_I2C_CONFIGUREPINS_I2C_SCL_NAME "I2C_SCL"
/* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_I2C_ConfigurePins(void);

#if defined(__cplusplus)
}
#endif

/*!
 * @}
 */
#endif /* _PIN_MUX_H_ */

/***********************************************************************************************************************
 * EOF
 **********************************************************************************************************************/
